Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute()
Execute is the main entry point for the CLI application. It adds all child commands to the root command, parses the command-line arguments, and executes the appropriate command. If an error occurs, it prints the error and exits. Execute 是 CLI 应用程序的主入口点。 它将所有子命令添加到根命令中,解析命令行参数,并执行相应的命令。 如果发生错误,它会打印错误并退出。
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.