Documentation
¶
Overview ¶
Package postgres provides a PostgreSQL implementation of the repository interfaces.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewAuditRepository ¶
func NewAuditRepository(db *pgxpool.Pool, auditCfg config.AuditConfig) *auditRepository
NewAuditRepository creates a new Audit repository.
func NewKLRRepository ¶
func NewKLRRepository(db *gorm.DB) service.KeyLifecycleRegistry
NewKLRRepository creates a new KLR repository.
func NewPostgresRiskRepository ¶
func NewPostgresRiskRepository(db *gorm.DB) repository.RiskRepository
NewPostgresRiskRepository creates a new PostgresRiskRepository.
Types ¶
type PostgresRiskRepository ¶
type PostgresRiskRepository struct {
// contains filtered or unexported fields
}
PostgresRiskRepository is a PostgreSQL implementation of the RiskRepository.
func (*PostgresRiskRepository) GetTenantRiskProfile ¶
func (r *PostgresRiskRepository) GetTenantRiskProfile(ctx context.Context, tenantID string) (*models.TenantRiskProfile, error)
GetTenantRiskProfile retrieves the risk profile for a given tenant.
func (*PostgresRiskRepository) UpsertTenantRiskProfile ¶
func (r *PostgresRiskRepository) UpsertTenantRiskProfile(ctx context.Context, profile *models.TenantRiskProfile) error
UpsertTenantRiskProfile creates or updates the risk profile for a tenant.
Click to show internal directories.
Click to hide internal directories.